#############################################################################
# (c) by Tels 2004-2005. Manual for Graph::Easy.
#
#############################################################################

package Graph::Easy::Manual;

use strict;

use vars qw/$VERSION/;
$VERSION = '0.22';

1;
__END__

=head1 NAME

Graph::Easy::Manual - HTML manual for Graph::Easy

=head1 SYNOPSIS

        cd doc
	./gen_manual

	# then open doc/manual/index.html in Browser

=head1 DESCRIPTION

A C<Graph::Easy::Manual> provides a comprehensive HTML manual
for Graph::Easy.

X<manual>
X<graph>
X<drawing>
X<flowchart>

=head1 SEE ALSO

L<Graph::Easy>.

=head1 AUTHOR

Copyright (C) 2004 - 2005 by Tels L<http://bloodgate.com>

This library is free software; you can redistribute it and/or modify
it under the same terms of the GPL version 2.

See the LICENSE file for more details.

X<tels>
X<gpl>
X<license>

=cut
